@@ -75,8 +75,8 @@ L_t_test_sample_size <- function(MW = 0.05, sd = 1, d = 1.2, S = 3, paired = FAL
       to <- (Xu-d*sd)*sqrt(n)/sd
       td <- (to-tmw)^2
     }
-    xmin1 <- optimize(f, c(3, 1000), tol = toler, MW, nul, d, sd, S)
-    ns <- round(xmin1$minimum,0)
+    xmin1 <- optimize(f, c(3, 10000000), tol = toler, MW, nul, d, sd, S)
+    ns <- ceiling(xmin1$minimum)   # use ceiling rather than round, to get to nearest N
 
     if(verb) cat("\nFor 1 sample, or related samples, t test with M1 + W1 probability of ", MW,
         "\n Strength of evidence required is ", S,
@@ -92,8 +92,8 @@ L_t_test_sample_size <- function(MW = 0.05, sd = 1, d = 1.2, S = 3, paired = FAL
       to <- (Xu-d*sd)*sqrt(n)/(2*sd)
       td <- (to-tmw)^2
     }
-    xmin1 <- optimize(g, c(3, 1000), tol = toler, MW, nul, d, sd, S)
-    ns <- round(xmin1$minimum,0)
+    xmin1 <- optimize(g, c(3, 10000000), tol = toler, MW, nul, d, sd, S)
+    ns <- ceiling(xmin1$minimum) # use ceiling rather than round, to get to nearest total N
 
     if (lapply(ns, "%%", 2) != 0) ns <- ns+1 # make even N for 2 samples
     if(verb) cat("\nFor independent samples t test with M1 + W1 probability of ", MW,
